@@ -8,7 +8,7 @@ use SWISH::Filter;
 use SWISH::Prog::Doc;
 use Scalar::Util qw( blessed );
 
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 __PACKAGE__->mk_accessors(
     qw( set_parser_from_type indexer doc_class swish_filter_obj ));
@@ -97,14 +97,7 @@ sub init {
         croak "SWISH::Prog::Indexer-derived object required";
     }
 
-    $self->{config} ||= $self->{indexer}->config;
-
-    if (   !blessed( $self->{config} )
-        or !$self->{config}->isa('SWISH::Prog::Config') )
-    {
-        croak "SWISH::Prog::Config-derived object required";
-    }
-
+    $self->{config} = $self->{indexer}->config;
     $self->{doc_class} ||= 'SWISH::Prog::Doc';
     $self->{swish_filter_obj} ||= SWISH::Filter->new;
 
